What's in scikit-COSMO?
=======================

``scikit-cosmo`` is a collection of `scikit-learn <https://scikit.org>`_ (sklearn)
compatible utilities that implement methods developed in the `COSMO laboratory <https://cosmo.epfl.ch>`_.

This package serves two purposes: 1) as a development ground for models and patches that may ultimately be suitable for inclusion
in sklearn, and 2) to coalesce field-specific sklearn-like routines and models in
a well-documented and standardized repository.

Currently, scikit-COSMO contains models described in [Imbalzano2018]_, [Helfrecht2020]_, [Goscinski2021]_ and [Cersonsky2021]_, as well
as some modifications to sklearn functionalities and minimal datasets that are useful within the field
of computational materials science and chemistry.

If you would like to contribute to scikit-COSMO, check out our :ref:`contributing` page!
